class Session:
    is_new = False
    is_established = False
    is_finised = False
    
    def __init__(self):
        self.tcp_seqnum = 0

    def get_seqnum(self, packet):
        seqnum = self.tcp_seqnum

        self.tcp_seqnum += len(packet['TCP'].payload)
        if self.tcp_seqnum > 2147483647: # 2^32 - 1
            self.tcp_seqnum = 0

        return seqnum

    def get_next(self):
        pass




import glob
import importlib
import importlib.util
import os

import pcraft.functions

class Functions:
    def __init__(self, plugins_data, functionsdir="pcraft/functions/"):
        self.loaded_functions = {}
        self.functions = glob.glob(functionsdir + "*.py")
        self.functions = [x for x in self.functions if not x.endswith("__init__.py")] # I do not want to include the __init__.py file
        self.functions = [x for x in self.functions if not x.endswith("_utils.py")]
        if not self.functions:
            print("No functions could be loaded from %s." % functionsdir)
            return
        
        for modfile in self.functions:
            function_name = os.path.basename(modfile)[:-3] # We remove the extension
            import_function = self._modularize_string_path(modfile)
            module = importlib.import_module(import_function)
            dp = module.PCraftFunction(plugins_data)
            self.loaded_functions[function_name] = dp

    def _modularize_string_path(self, strpath):
        return strpath.replace("/",".")[:-3]

    def get_loaded_functions(self):
        return self.loaded_functions



import glob
import importlib
import importlib.util
import os

import pcraft.plugins
from pcraft.PluginsData import *
from pcraft.Sessionizer import *

class Plugins:
    def __init__(self, pluginsdir="pcraft/plugins/", arguments_dealer=None, loadfunc=None):
        self.loaded_plugins = {}
        self.arguments_dealer = arguments_dealer
        self.plugins = glob.glob(pluginsdir + "*.py")
        self.plugins = [x for x in self.plugins if not x.endswith("__init__.py")] # I do not want to include the __init__.py file
        self.plugins = [x for x in self.plugins if not x.endswith("_utils.py")]
        if not self.plugins:
            raise Exception("No Plugins found from %s; The engine is useless!" % pluginsdir)
        print(self.plugins)

        self.plugins_data = PluginsData()
        self.session = Session()
        
        for modfile in self.plugins:
            plugin_name = os.path.basename(modfile)[:-3] # We remove the extension
            import_plugin = self._modularize_string_path(modfile)
            module = importlib.import_module(import_plugin)
            dp = module.PCraftPlugin(self.session, self.plugins_data)
            self.loaded_plugins[plugin_name] = dp
            #            dp.run()
            #self.loaded_plugins[plugin_name] = dp
            
            # spec = importlib.util.spec_from_file_location(self._modularize_string_path(modfile),modfile)
            # module = importlib.util.module_from_spec(spec)
            # if module and loadfunc:
            #     loadfunc(plugin_name)
            # spec.loader.exec_module(module)(arguments_dealer)
            # self.loaded_plugins[plugin_name] = module

    def _modularize_string_path(self, strpath):
        return strpath.replace("/",".")[:-3]

    def get_loaded_plugins(self):
        return self.loaded_plugins

    def get_plugins_data(self):
        return self.plugins_data



class PluginsData(object):
    def __init__(self):
        self.pcap = []
        self.args = {}

    def _set(self, key, value):
        self.args[key] = value

    def _get(self, key):
        return self.args[key]

    def __str__(self):
        return str(self.args)
        



#!/usr/bin/python
import setuptools
from distutils.core import setup
import os
import textwrap

current_dir = os.path.abspath(os.path.dirname(__file__))

about = {}
with open(os.path.join(current_dir, "pcraft", "__version__.py"), "r") as fp:
          exec(fp.read(), about)

setup(name="pcraft",
      version=about["__version__"],
      author=about["__author__"],
      author_email=about["__author_email__"],
      description=about["__description__"],
      long_description=textwrap.dedent(open("README.md", "r").read()),
      long_description_content_type="text/markdown",
      maintainer=about["__maintainer__"],
      maintainer_email=about["__maintainer_email__"],
      url=about["__url__"],
      license=about["__license__"],
      classifiers=[
          "Programming Language :: Python :: 3",
          "License :: OSI Approved :: MIT License",
          "Operating System :: OS Independent",
      ],
      install_requires=[
          "scapy",
          "IPy",
          "PyYAML",
          "dnspython",
      ],
      scripts=["pcrafter"],
      packages=["pcraft"])



"""Version and details for pcraft"""

__description__ = "Pcraft"
__url__ = "https://www.github.com/devoinc/pcraft"
__version__ = "0.0.7"
__author__ = "Sebastien Tricaud"
__author_email__ = "sebastien.tricaud@devo.com"
__license__ = "MIT"
__maintainer__ = __author__
__maintainer_email__ = __author_email__
